/* ***** BEGIN LICENSE BLOCK *****
 * FW4SPL - Copyright (C) IRCAD, 2009-2015.
 * Distributed under the terms of the GNU Lesser General Public License (LGPL) as
 * published by the Free Software Foundation.
 * ****** END LICENSE BLOCK ****** */

#ifndef __FWTOOLS_NAMESPACE_HPP__
#define __FWTOOLS_NAMESPACE_HPP__

/**
 * @brief       The namespace fwTools contains several tools like UUID, factory, dispatche, stringizer, macros, helper.
 * @namespace   fwTools
 *
 * @date        2009-2010.
 *
 */
namespace fwTools
{
}
#endif /* __FWTOOLS_NAMESPACE_HPP__ */
